.. image:: https://badge.fury.io/py/labml-dashboard.svg
    :target: https://badge.fury.io/py/labml-dashboard


LabML Dashboard
================

This is the web dashboard for `LabML <https://github.com/lab-ml/labml/>`_.

`💬 Slack workspace for discussions <https://join.slack.com/t/labforml/shared_invite/zt-egj9zvq9-Dl3hhZqobexgT7aVKnD14g/>`_

`📗 Documentation <http://lab-ml.com/>`_

`📑 Articles & Tutorials <https://medium.com/@labml/>`_

`👨‍🏫 Samples <https://github.com/lab-ml/samples>`_

Here are some screenshots.

.. image:: https://raw.githubusercontent.com/lab-ml/dashboard/master/images/screenshots/dashboard_table.png
   :width: 100%
   :alt: Dashboard Screenshot

.. image:: https://raw.githubusercontent.com/lab-ml/dashboard/master/images/screenshots/dashboard_run.png
   :width: 100%
   :alt: Dashboard Screenshot

Install
-------

.. code-block:: console

    pip install labml_dashboard

Running
-------

Navigate to the path of the project and run the following command to start the server.

.. code-block:: console

    labml dashboard
